@@ -5,15 +5,15 @@
  *
  *      Description:  Implementation of access daemon.
  *
- *      Version:   4.3.3
- *      Released:  09.11.2018
+ *      Version:   4.3.4
+ *      Released:  05.04.2019
  *
  *      Authors:  Michael Meier, michael.meier@rrze.fau.de
  *                Jan Treibig (jt), jan.treibig@gmail.com,
  *                Thomas Roehl (tr), thomas.roehl@googlemail.com
  *      Project:  likwid
  *
- *      Copyright (C) 2018 RRZE, University Erlangen-Nuremberg
+ *      Copyright (C) 2019 RRZE, University Erlangen-Nuremberg
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -49,6 +49,7 @@
 #include <sys/fsuid.h>
 #include <getopt.h>
 #include <dirent.h>
+#include <fnmatch.h>
 
 #include <types.h>
 #include <registers.h>
@@ -122,43 +123,106 @@ static int num_pmc_counters = 0;
  */
 static int avail_sockets = 0;
 static int avail_cpus = 0;
+static int avail_nodes = 0;
+
+static int getNumberOfCPUs()
+{
+    FILE* fpipe = NULL;
+    char cmd[1024] = "cat /proc/cpuinfo | grep \"processor\" | sort -u | wc -l";
+    char buff[1024];
+    if ( !(fpipe = popen(cmd,"r")) )
+    {
+        return 0;
+    }
+    char* ptr = fgets(buff, 1024, fpipe);
+    if (ptr)
+    {
+        return atoi(buff);
+    }
+    return 0;
+}
+
+static int getNumberOfSockets()
+{
+    FILE* fpipe = NULL;
+    char cmd[1024] = "cat /proc/cpuinfo | grep \"physical id\" | sort -u | wc -l";
+    char buff[1024];
+    if ( !(fpipe = popen(cmd,"r")) )
+    {
+        return 0;
+    }
+    char* ptr = fgets(buff, 1024, fpipe);
+    if (ptr)
+    {
+        return atoi(buff);
+    }
+    return 0;
+}
+
+static int getNumberOfNumaNodes()
+{
+    DIR *dp = NULL;
+    struct dirent *ep = NULL;
+    int count = 0;
+    dp = opendir ("/sys/devices/system/node/");
+    if (dp != NULL)
+    {
+        while (ep = readdir (dp))
+        {
+            if (fnmatch("node?*", ep->d_name, FNM_PATHNAME) == 0)
+            {
+                count++;
+            }
+        }
+        closedir(dp);
+    }
+    return count;
+}
 
 void __attribute__((constructor (101))) init_accessdaemon(void)
 {
-    FILE *fpipe = NULL;
-    char *ptr = NULL;
+
     FILE *rdpmc_file = NULL;
     FILE *nmi_watchdog_file = NULL;
-    char cmd_cpu[] = "cat /proc/cpuinfo  | grep 'processor' | sort -u | wc -l";
-    char cmd_sock[] = "cat /proc/cpuinfo  | grep 'physical id' | sort -u | wc -l";
-    //static long avail_sockets = 0;
-    char buff[256];
-    //avail_cpus = sysconf(_SC_NPROCESSORS_CONF);
+    int retries = 10;
 
-    if ( !(fpipe = (FILE*)popen(cmd_cpu,"r")) )
-    {  // If fpipe is NULL
-        return;
-    }
-    ptr = fgets(buff, 256, fpipe);
-    if (pclose(fpipe))
-        return;
-    avail_cpus = atoi(buff);
-
-    if ( !(fpipe = (FILE*)popen(cmd_sock,"r")) )
-    {  // If fpipe is NULL
-        return;
-    }
-    ptr = fgets(buff, 256, fpipe);
-    if (pclose(fpipe))
-        return;
-    avail_sockets = atoi(buff);
+    do {
+        avail_cpus = getNumberOfCPUs();
+        retries--;
+    } while (avail_cpus == 0 && retries > 0);
+    if (retries <= 0) return;
+    retries = 10;
+    do {
+        avail_sockets = getNumberOfSockets();
+        retries--;
+    } while (avail_sockets == 0 && retries > 0);
+    if (retries <= 0) return;
+    retries = 10;
+    do {
+        avail_nodes = getNumberOfNumaNodes();
+        retries--;
+    } while (avail_nodes == 0 && retries > 0);
+    if (retries <= 0) return;
 
     FD_MSR = malloc(avail_cpus * sizeof(int));
+    if (!FD_MSR)
+        return;
 
     FD_PCI = malloc(avail_sockets * sizeof(int*));
+    if (!FD_PCI)
+        return;
     for (int i = 0; i < avail_sockets; i++)
     {
         FD_PCI[i] = malloc(MAX_NUM_PCI_DEVICES * sizeof(int));
+        if (!FD_PCI[i])
+        {
+            for (int j = i-1; j >= 0; j--)
+            {
+                free(FD_PCI[j]);
+            }
+            free(FD_PCI);
+            return;
+        }
     }
     // Explicitly allow RDPMC instruction
     rdpmc_file = fopen("/sys/bus/event_source/devices/cpu/rdpmc", "wb");
@@ -178,16 +242,24 @@ void __attribute__((constructor (101))) init_accessdaemon(void)
 
 void __attribute__((destructor (101))) close_accessdaemon(void)
 {
-    for (int i = 0; i < avail_sockets; i++)
+    if (FD_PCI)
     {
-        free(FD_PCI[i]);
-        FD_PCI[i] = NULL;
+        for (int i = 0; i < avail_sockets; i++)
+        {
+            if (FD_PCI[i])
+            {
+                free(FD_PCI[i]);
+                FD_PCI[i] = NULL;
+            }
+        }
+        free(FD_PCI);
+        FD_PCI = NULL;
+    }
+    if (FD_MSR)
+    {
+        free(FD_MSR);
+        FD_MSR = NULL;
     }
-    free(FD_PCI);
-    FD_PCI = NULL;
-
-    free(FD_MSR);
-    FD_MSR = NULL;
 }
 
 /* #####   FUNCTION DEFINITIONS  -  LOCAL TO THIS SOURCE FILE   ########### */
@@ -696,7 +768,7 @@ static int allowed_skx(uint32_t reg)
             (reg == MSR_PREFETCH_ENABLE) ||
             ((reg & 0xA00U) == 0xA00U))
             return 1;
-    }   
+    }
     return 0;
 }
 
@@ -1108,14 +1180,142 @@ static int getBusFromSocketByDevid(const uint32_t socket, PciDevice* pcidev, int
 }
 
 
+static int get_devid(int pathlen, char* path)
+{
+    uint32_t devid = 0x0;
+    int ret = 0;
+    char devidpath[1024];
+    char buff[1024];
+
+    ret = snprintf(devidpath, 1023, "%.*s/device", pathlen, path);
+    if (ret)
+    {
+        devidpath[ret] = '\0';
+        FILE *fp = fopen(devidpath, "r");
+        if (fp)
+        {
+            ret = fread(buff, sizeof(char), 1023, fp);
+            if (ret)
+            {
+                buff[ret] = '\0';
+                ret = sscanf(buff, "%x", &devid);
+                if (ret == 1)
+                {
+                    devid = -1;
+                }
+            }
+            fclose(fp);
+        }
+    }
+    return 0x0;
+}
+
+static int get_nodeid(int pathlen, char* path)
+{
+    int nodeid = -1;
+    int ret = 0;
+    char devidpath[1024];
+    char buff[1024];
+
+    ret = snprintf(devidpath, 1023, "%.*s/numa_node", pathlen, path);
+    if (ret)
+    {
+        devidpath[ret] = '\0';
+        FILE *fp = fopen(devidpath, "r");
+        if (fp)
+        {
+            ret = fread(buff, sizeof(char), 1023, fp);
+            if (ret)
+            {
+                buff[ret] = '\0';
+                ret = sscanf(buff, "%d", &nodeid);
+                if (ret != 1)
+                {
+                    nodeid = -1;
+                }
+            }
+            fclose(fp);
+        }
+    }
+    return nodeid;
+}
+
+static int getBusFromSocketByNameDevidNode(const uint32_t socket, PciDevice* pcidev, int pathlen, char** filepath)
+{
+    FILE *fpipe = NULL;
+    int isSNC = 0;
+    int SNCscale = 1;
+    if (avail_sockets != avail_nodes)
+    {
+        isSNC = 1;
+        SNCscale = avail_nodes/avail_sockets;
+    }
+    uint32_t devid = 0x0;
+    int nodeid = -1;
+    char cmd[1024];
+    char buff[1024];
+    int ret = 0;
+
+    snprintf(cmd, 1023, "ls -d /sys/bus/pci/devices/*%s* 2>/dev/null", pcidev->path);
+    if ( !(fpipe = popen(cmd,"r")) )
+    {
+        return -1;
+    }
+    while ((fgets(buff, 1024, fpipe)) != NULL)
+    {
+        if (strncmp(buff, ".", 1) == 0) continue;
+        devid = get_devid((int)(strlen(buff)-1), buff);
+        if (devid == 0) continue;
+        nodeid = get_nodeid((int)(strlen(buff)-1), buff);
+        if (nodeid < 0) continue;
+        nodeid /= SNCscale;
+        if (devid == pcidev->devid && nodeid == socket)
+        {
+            int mid = 0;
+            int start = 0;
+            for (int i= strlen(buff)-1; i>= 0; i--)
+            {
+                if (mid == 0 && buff[i] == ':')
+                {
+                    mid = i+1;
+                    continue;
+                }
+                if (mid > 0 && start == 0 && buff[i] == ':')
+                {
+                    start = i+1;
+                }
+            }
+            if (filepath && *filepath && pathlen > 0 && mid > 0 && start > 0)
+            {
+                ret = snprintf(*filepath, pathlen-1, "/proc/bus/pci/%.*s/%.*s", (int)(mid-start-1), &(buff[start]), (int)(strlen(buff)-mid-1), &(buff[mid]));
+                if (ret > 0)
+                    (*filepath)[ret] = '\0';
+            }
+            fclose(fpipe);
+            return socket;
+        }
+    }
+    fclose(fpipe);
+    return -1;
+}
+
+
 static int getBusFromSocket(const uint32_t socket, PciDevice* pcidev, int pathlen, char** filepath)
 {
     int ret_sock = -1;
-    int ret = getBusFromSocketByNameDevid(socket, pcidev, pathlen, filepath);
+    int ret = getBusFromSocketByNameDevidNode(socket, pcidev, pathlen, filepath);
     if (ret < 0)
     {
-        ret = getBusFromSocketByDevid(socket, pcidev, pathlen, filepath);
-        if (ret > 0)
+        ret = getBusFromSocketByNameDevid(socket, pcidev, pathlen, filepath);
+        if (ret < 0)
+        {
+            ret = getBusFromSocketByDevid(socket, pcidev, pathlen, filepath);
+            if (ret >= 0)
+            {
+                ret_sock = socket;
+            }
+        }
+        else
         {
             ret_sock = socket;
         }
@@ -1274,7 +1474,7 @@ pci_write(AccessDataRecord* dRecord)
                 return;
             }
         }
-        
+
     }
 
     if (!isPCI64)
@@ -1706,10 +1906,12 @@ int main(void)
                         }
                         pci_devices_daemon[i].online = 1;
                     }
+#ifdef DEBUG_LIKWID
                     else
                     {
-                        syslog(LOG_ERR, "Device %s for socket %d, excluded it from device list: %s\n",pci_devices_daemon[i].name, 0, strerror(errno));
+                        syslog(LOG_ERR, "Device %s not found, excluded it from device list\n",pci_devices_daemon[i].name);
                     }
+#endif
                 }
             }
         }
