@@ -6,13 +6,13 @@
  *
  *      Description:  A application to retrieve and manipulate CPU features.
  *
- *      Version:   4.3.2
- *      Released:  12.04.2018
+ *      Version:   4.3.4
+ *      Released:  05.04.2019
  *
  *      Author:   Thomas Roehl (tr), thomas.roehl@gmail.com
  *      Project:  likwid
  *
- *      Copyright (C) 2018 RRZE, University Erlangen-Nuremberg
+ *      Copyright (C) 2019 RRZE, University Erlangen-Nuremberg
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -79,7 +79,7 @@ for opt,arg in likwid.getopt(arg, {"h","v","l","c:","e:","d:","a","help","versio
     if (type(arg) == "string") then
         local s,e = arg:find("-");
         if s == 1 then
-            print_stderr(string.format("Argmument %s to option -%s starts with invalid character -.", arg, opt))
+            print_stderr(string.format("Argument %s to option -%s starts with invalid character -.", arg, opt))
             print_stderr("Did you forget an argument to an option?")
             os.exit(1)
         end
@@ -150,23 +150,26 @@ end
 likwid.initCpuFeatures()
 
 if listFeatures and #cpulist > 0 then
-    local str = "Feature"..string.rep(" ",string.len("BRANCH_TRACE_STORAGE")-string.len("Feature")+2)
-    for j, c in pairs(cpulist) do
-        str = str..string.format("CPU %d\t",c)
-    end
-    print_stdout(str)
-    str = ""
-    for i=0,likwid.tablelength(likwid.cpuFeatures)-1 do
-        str = likwid.cpuFeatures[i]..string.rep(" ",string.len("BRANCH_TRACE_STORAGE")-string.len(likwid.cpuFeatures[i])+2)
+    if likwid.getCpuFeatures(c, 0) >= 0 then
+        local str = "Feature"..string.rep(" ",string.len("BRANCH_TRACE_STORAGE")-string.len("Feature")+2)
         for j, c in pairs(cpulist) do
-            if (likwid.getCpuFeatures(c, i) == 1) then
-                str = str .. "on\t"
-            else
-                str = str .. "off\t"
-            end
+            str = str..string.format("CPU %d\t",c)
         end
         print_stdout(str)
+        str = ""
+        for i=0,likwid.tablelength(likwid.cpuFeatures)-1 do
+            str = likwid.cpuFeatures[i]..string.rep(" ",string.len("BRANCH_TRACE_STORAGE")-string.len(likwid.cpuFeatures[i])+2)
+            for j, c in pairs(cpulist) do
+                if (likwid.getCpuFeatures(c, i) == 1) then
+                    str = str .. "on\t"
+                else
+                    str = str .. "off\t"
+                end
+            end
+            print_stdout(str)
+        end
     end
+    os.exit(1)
 elseif #cpulist == 0 then
     print_stderr("Need CPU to list current feature state")
     os.exit(1)
