@@ -7,13 +7,13 @@
  *      Description: A wrapper script to pin threads spawned by MPI processes and
  *                   measure hardware performance counters
  *
- *      Version:   4.3.3
- *      Released:  09.11.2018
+ *      Version:   4.3.4
+ *      Released:  05.04.2019
  *
  *      Author:   Thomas Roehl (tr), thomas.roehl@googlemail.com
  *      Project:  likwid
  *
- *      Copyright (C) 2018 RRZE, University Erlangen-Nuremberg
+ *      Copyright (C) 2019 RRZE, University Erlangen-Nuremberg
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -1133,7 +1133,7 @@ local function setPerfStrings(perflist, cpuexprs)
         end
     end
     if #grouplist == 0 then
-        print_stderr("No group can be configured for measurments, exiting.")
+        print_stderr("No group can be configured for measurements, exiting.")
         os.exit(1)
     end
     return perfexprs, grouplist
@@ -1589,6 +1589,8 @@ function printMpiOutput(group_list, all_results, regionname)
         local secondtab_combined = {}
         local total_threads = 0
         local all_counters = {}
+        local groupName = gdata["GroupString"]
+
         for rank = 0, #all_results do
             total_threads = total_threads + #all_results[rank]["cpus"]
         end
@@ -1687,14 +1689,35 @@ function printMpiOutput(group_list, all_results, regionname)
                 if #secondtab_combined > maxLineFields then maxLineFields = #secondtab_combined end
             end
             if region then
-                print_stdout("Region,"..tostring(region).. string.rep(",", maxLineFields  - 2))
+                print_stdout(string.format("TABLE,Region %s,Group %d Raw,%s,%d%s",tostring(region), gidx,groupName,#firsttab[1]-1,string.rep(",",maxLineFields-5)))
+            else
+                print_stdout(string.format("TABLE,Group %d Raw,%s,%d%s",gidx,groupName,#firsttab[1]-1,string.rep(",",maxLineFields-4)))
             end
-            print_stdout("Group,"..tostring(gidx) .. string.rep(",", maxLineFields  - 2))
+            --print_stdout("Group,"..tostring(gidx) .. string.rep(",", maxLineFields  - 2))
             likwid.printcsv(firsttab, maxLineFields)
-            if total_threads > 1 then likwid.printcsv(firsttab_combined, maxLineFields) end
+            if total_threads > 1 then
+                if region == nil then
+                    print(string.format("TABLE,Group %d Raw STAT,%s,%d%s",gidx,groupName,#firsttab_combined[1]-1,string.rep(",",maxLineFields-4)))
+                else
+                    print(string.format("TABLE,Region %s,Group %d Raw STAT,%s,%d%s",regionName, gidx,groupName,#firsttab_combined[1]-1,string.rep(",",maxLineFields-5)))
+                end
+                likwid.printcsv(firsttab_combined, maxLineFields)
+            end
             if gdata["Metrics"] then
+                if region == nil then
+                    print(string.format("TABLE,Group %d Metric,%s,%d%s",gidx,groupName,#secondtab[1]-1,string.rep(",",maxLineFields-4)))
+                else
+                    print(string.format("TABLE,Region %s,Group %d Metric,%s,%d%s",regionName,gidx,groupName,#secondtab[1]-1,string.rep(",",maxLineFields-5)))
+                end
                 likwid.printcsv(secondtab, maxLineFields)
-                if total_threads > 1 then likwid.printcsv(secondtab_combined, maxLineFields) end
+                if total_threads > 1 then
+                    if region == nil then
+                        print(string.format("TABLE,Group %d Metric STAT,%s,%d%s",gidx,groupName,#secondtab_combined[1]-1,string.rep(",",maxLineFields-4)))
+                    else
+                        print(string.format("TABLE,Region %s,Group %d Metric STAT,%s,%d%s",regionName,gidx,groupName,#secondtab_combined[1]-1,string.rep(",",maxLineFields-5)))
+                    end
+                    likwid.printcsv(secondtab_combined, maxLineFields)
+                end
             end
         else
             if region then
@@ -1739,7 +1762,7 @@ for opt,arg in likwid.getopt(arg,  cmd_options) do
     if (type(arg) == "string") then
         local s,e = arg:find("-")
         if s == 1 then
-            print_stderr(string.format("ERROR: Argmument %s to option -%s starts with invalid character -.", arg, opt))
+            print_stderr(string.format("ERROR: Argument %s to option -%s starts with invalid character -.", arg, opt))
             print_stderr("ERROR: Did you forget an argument to an option?")
             os.exit(1)
         end
@@ -1914,7 +1937,7 @@ if not hostfile then
     elseif os.getenv("LOADL_HOSTFILE") ~= nil then
         hostfile = os.getenv("LOADL_HOSTFILE")
         hosts = readHostfilePBS(hostfile)
-    elseif mpitype == "slurm" and os.getenv("SLURM_NODELIST") ~= nil then
+    elseif os.getenv("SLURM_NODELIST") ~= nil then
         hostlist = os.getenv("SLURM_NODELIST")
         hosts = readHostfileSlurm(hostlist)
     else
