@@ -7,13 +7,13 @@
  *      Description:  An application to read out performance counter registers
  *                    on x86 processors
  *
- *      Version:   4.3.3
- *      Released:  09.11.2018
+ *      Version:   4.3.4
+ *      Released:  05.04.2019
  *
  *      Author:   Thomas Roehl (tr), thomas.roehl@googlemail.com
  *      Project:  likwid
  *
- *      Copyright (C) 2018 RRZE, University Erlangen-Nuremberg
+ *      Copyright (C) 2019 RRZE, University Erlangen-Nuremberg
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -155,7 +155,7 @@ for opt,arg in likwid.getopt(arg, {"a", "c:", "C:", "e", "E:", "g:", "h", "H", "
     if (type(arg) == "string") then
         local s,e = arg:find("-");
         if s == 1 then
-            print_stderr(string.format("Argmument %s to option -%s starts with invalid character -.", arg, opt))
+            print_stderr(string.format("Argument %s to option -%s starts with invalid character -.", arg, opt))
             print_stderr("Did you forget an argument to an option?")
             os.exit(1)
         end
@@ -951,16 +951,16 @@ elseif use_timeline == false then
     likwid.printOutput(results, metrics, cpulist, nil, print_stats)
 end
 
-if outfile and outfile ~= outfile_orig then
+if outfile then
     local suffix = ""
-    if string.match(outfile,".-[^\\/]-%.?([^%.\\/]*)$") then
+    if string.match(outfile, ".-[^\\/]-%.?([^%.\\/]*)$") then
         suffix = string.match(outfile, ".-[^\\/]-%.?([^%.\\/]*)$")
     end
     local command = "<INSTALLED_PREFIX>/share/likwid/filter/" .. suffix
     local tmpfile = outfile..".tmp"
     if suffix == "" then
         os.rename(tmpfile, outfile)
-    elseif suffix ~= "txt" and suffix ~= "csv" and not likwid.access(command, "x") then
+    elseif suffix ~= "txt" and suffix ~= "csv" and not likwid.access(command,"x") then
         print_stderr("Cannot find filter script, save output in CSV format to file "..outfile)
         os.rename(tmpfile, outfile)
     else
