@@ -6,13 +6,13 @@
  *
  *      Description:  An application to pin a program including threads
  *
- *      Version:   4.3.2
- *      Released:  12.04.2018
+ *      Version:   4.3.4
+ *      Released:  05.04.2019
  *
  *      Author:   Thomas Roehl (tr), thomas.roehl@gmail.com
  *      Project:  likwid
  *
- *      Copyright (C) 2018 RRZE, University Erlangen-Nuremberg
+ *      Copyright (C) 2019 RRZE, University Erlangen-Nuremberg
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -177,7 +177,7 @@ if cpustr ~= nil then
         close_and_exit(1)
     end
     if verbose > 0 and quiet == 0 then
-        print_stdout("Evaluated CPU string to CPUs: ")
+        print_stdout("Evaluated CPU string to CPUs: " .. cpustr)
     end
 end
 
@@ -277,7 +277,12 @@ if verbose > 0 and quiet == 0 then
     print_stdout("Running: " .. exec)
     mask = 0
     for _, c in pairs(cpu_list) do
-        mask = mask | (1<<c)
+        -- Check whether the Lua version has bit32 module (>= 5.2)
+        if not bit32 then
+            mask = mask | (1<<c)
+        else
+            mask = bit32.bor(mask, bit32.lshift(1, c))
+        end
     end
     print_stdout(string.format("Using %d thread(s) (cpuset: 0x%x)", num_threads, mask))
 end
