@@ -6,13 +6,13 @@
  *
  *      Description:  A application to set the CPU frequency of CPU cores and domains.
  *
- *      Version:   4.3.3
- *      Released:  09.11.2018
+ *      Version:   4.3.4
+ *      Released:  05.04.2019
  *
  *      Author:   Thomas Roehl (tr), thomas.roehl@gmail.com
  *      Project:  likwid
  *
- *      Copyright (C) 2018 RRZE, University Erlangen-Nuremberg
+ *      Copyright (C) 2019 RRZE, University Erlangen-Nuremberg
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -163,6 +163,7 @@ for opt,arg in likwid.getopt(arg, {"V:", "g:", "c:", "f:", "l", "p", "h", "v", "
         local s = tonumber(arg)
         if (s >= 0 and s <= 3) then
             verbosity = s
+            likwid.setVerbosity(s)
         else
             print_stderr(string.format("ERROR: Value %s for verbosity not valid", arg))
         end
@@ -317,7 +318,24 @@ if do_reset then
         max_freq = availfreqs[#availfreqs]
     end
     if not governor then
-        governor = availgovs[#availgovs]
+        governor = nil
+        for i, g in pairs(availgovs) do
+            if g:match("^performance") then
+                governor = g
+                break
+            end
+        end
+        if not governor then
+            for i, g in pairs(availgovs) do
+                if g:match("^conservative") then
+                    governor = g
+                    break
+                end
+            end
+            if not governor then
+                governor = availgovs[#availgovs]
+            end
+        end
     end
     if min_freq and governor then
         print_stdout(string.format("Reset to governor %s with min freq. %g GHz and deactivate turbo mode", governor, min_freq))
