@@ -5,14 +5,14 @@
  *
  *      Description:  Marker API interface of module perfmon
  *
- *      Version:   4.3.3
- *      Released:  09.11.2018
+ *      Version:   4.3.4
+ *      Released:  05.04.2019
  *
  *      Authors:  Jan Treibig (jt), jan.treibig@gmail.com
  *                Thomas Roehl (tr), thomas.roehl@googlemail.com
  *      Project:  likwid
  *
- *      Copyright (C) 2018 RRZE, University Erlangen-Nuremberg
+ *      Copyright (C) 2019 RRZE, University Erlangen-Nuremberg
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -273,10 +273,9 @@ likwid_markerInit(void)
     registered_cpus++;
 
     groupSet->activeGroup = 0;
-//#ifdef LIKWID_USE_PERFEVENT
+
     perfmon_setupCounters(groupSet->activeGroup);
     perfmon_startCounters();
-//#endif
 }
 
 void
@@ -509,12 +508,13 @@ likwid_markerRegisterRegion(const char* regionTag)
     int cpu_id = hashTable_get(tag, &results);
     bdestroy(tag);
 
-    // Add CPU to access layer
+#ifndef LIKWID_USE_PERFEVENT
+    // Add CPU to access layer if ACCESSMODE is direct or accessdaemon
     ret =  HPMaddThread(cpu_id);
     // Perform one access to fully initialize connection to access daemon
     uint32_t reg = counter_map[groupSet->groups[groups[0]].events[0].index].counterRegister;
     HPMread(cpu_id, MSR_DEV, reg, &tmp);
-
+#endif
     return ret;
 }
 
