@@ -5,14 +5,14 @@
  *
  *      Description:  Interface to the topology backends
  *
- *      Version:   4.3.3
- *      Released:  09.11.2018
+ *      Version:   4.3.4
+ *      Released:  05.04.2019
  *
  *      Authors:  Jan Treibig (jt), jan.treibig@gmail.com,
  *                Thomas Roehl (tr), thomas.roehl@googlemail.com
  *      Project:  likwid
  *
- *      Copyright (C) 2018 RRZE, University Erlangen-Nuremberg
+ *      Copyright (C) 2019 RRZE, University Erlangen-Nuremberg
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -61,6 +61,7 @@ static char* atom_silvermont_str = "Intel Atom (Silvermont) processor";
 static char* atom_airmont_str = "Intel Atom (Airmont) processor";
 static char* atom_goldmont_str = "Intel Atom (Goldmont) processor";
 static char* atom_goldmontplus_str = "Intel Atom (Goldmont Plus) processor";
+static char* atom_tremont_str = "Intel Atom (Tremont) processor";
 static char* nehalem_bloom_str = "Intel Core Bloomfield processor";
 static char* nehalem_lynn_str = "Intel Core Lynnfield processor";
 static char* nehalem_west_str = "Intel Core Westmere processor";
@@ -657,7 +658,7 @@ topology_setName(void)
                     break;
 
                 case SKYLAKEX:
-                    if (cpuid_info.stepping >= 0 && cpuid_info.stepping <= 5)
+                    if (cpuid_info.stepping >= 0 && cpuid_info.stepping < 5)
                     {
                         cpuid_info.name = skylakeX_str;
                         cpuid_info.short_name = short_skylakeX;
@@ -745,11 +746,14 @@ topology_setName(void)
                     cpuid_info.name = atom_goldmont_str;
                     cpuid_info.short_name = short_goldmont;
                     break;
-                
                 case ATOM_GOLDMONT_PLUS:
                     cpuid_info.name = atom_goldmontplus_str;
                     cpuid_info.short_name = short_goldmontplus;
                     break;
+                case ATOM_TREMONT:
+                    cpuid_info.name = atom_tremont_str;
+                    cpuid_info.short_name = short_goldmontplus;
+                    break;
 
                 default:
                     cpuid_info.name = unknown_intel_str;
