@@ -5,14 +5,14 @@
  *
  *      Description:  Interface to the hwloc based topology backend
  *
- *      Version:   4.3.2
- *      Released:  12.04.2018
+ *      Version:   4.3.4
+ *      Released:  05.04.2019
  *
  *      Authors:  Thomas Roehl (tr), thomas.roehl@googlemail.com
  *
  *      Project:  likwid
  *
- *      Copyright (C) 2018 RRZE, University Erlangen-Nuremberg
+ *      Copyright (C) 2019 RRZE, University Erlangen-Nuremberg
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -110,7 +110,7 @@ hwloc_init_cpuInfo(cpu_set_t cpuSet)
     if (!hwloc_topology)
     {
         likwid_hwloc_topology_init(&hwloc_topology);
-        likwid_hwloc_topology_set_flags(hwloc_topology, HWLOC_TOPOLOGY_FLAG_WHOLE_IO );
+        likwid_hwloc_topology_set_flags(hwloc_topology, HWLOC_TOPOLOGY_FLAG_WHOLE_SYSTEM|HWLOC_TOPOLOGY_FLAG_WHOLE_IO );
         likwid_hwloc_topology_load(hwloc_topology);
     }
     obj = likwid_hwloc_get_obj_by_type(hwloc_topology, HWLOC_OBJ_SOCKET, 0);
@@ -139,6 +139,8 @@ hwloc_init_cpuInfo(cpu_set_t cpuSet)
         cpuid_info.stepping = atoi(info);
 
     cpuid_topology.numHWThreads = likwid_hwloc_get_nbobjs_by_type(hwloc_topology, HWLOC_OBJ_PU);
+    if (cpuid_topology.activeHWThreads > cpuid_topology.numHWThreads)
+        cpuid_topology.numHWThreads = cpuid_topology.activeHWThreads;
     DEBUG_PRINT(DEBUGLEV_DEVELOP, HWLOC CpuInfo Family %d Model %d Stepping %d isIntel %d numHWThreads %d activeHWThreads %d,
                             cpuid_info.family,
                             cpuid_info.model,
@@ -282,6 +284,35 @@ hwloc_init_nodeTopology(cpu_set_t cpuSet)
                             hwThreadPool[id].inCpuSet)
     }
 
+    int socket_nums[16];
+    int num_sockets = 0;
+    for (uint32_t i=0; i< cpuid_topology.numHWThreads; i++)
+    {
+        int found = 0;
+        for (uint32_t j=0; j < num_sockets; j++)
+        {
+            if (hwThreadPool[i].packageId == socket_nums[j])
+            {
+                found = 1;
+                break;
+            }
+        }
+        if (!found)
+        {
+            socket_nums[num_sockets] = hwThreadPool[i].packageId;
+            num_sockets++;
+        }
+    }
+    for (uint32_t i=0; i< cpuid_topology.numHWThreads; i++)
+    {
+        for (uint32_t j=0; j < num_sockets; j++)
+        {
+            if (hwThreadPool[i].packageId == socket_nums[j])
+            {
+                hwThreadPool[i].packageId = j;
+            }
+        }
+    }
     cpuid_topology.threadPool = hwThreadPool;
     cpuid_topology.numThreadsPerCore = maxNumLogicalProcsPerCore;
     cpuid_topology.numCoresPerSocket = maxNumCoresPerSocket;
@@ -289,6 +320,29 @@ hwloc_init_nodeTopology(cpu_set_t cpuSet)
     return;
 }
 
+void hwloc_split_llc_check(CacheLevel* llc_cache)
+{
+    hwloc_obj_t obj = NULL;
+    int num_sockets = likwid_hwloc_get_nbobjs_by_type(hwloc_topology, HWLOC_OBJ_SOCKET);
+    int num_nodes = likwid_hwloc_get_nbobjs_by_type(hwloc_topology, HWLOC_OBJ_NODE);
+    if (num_sockets == num_nodes)
+    {
+        return;
+    }
+    obj = likwid_hwloc_get_obj_by_type(hwloc_topology, HWLOC_OBJ_SOCKET, 0);
+    int num_threads_per_socket = likwid_hwloc_record_objs_of_type_below_obj(hwloc_topology, obj, HWLOC_OBJ_PU, NULL, NULL);
+    obj = likwid_hwloc_get_obj_by_type(hwloc_topology, HWLOC_OBJ_NODE, 0);
+    int num_threads_per_node = likwid_hwloc_record_objs_of_type_below_obj(hwloc_topology, obj, HWLOC_OBJ_PU, NULL, NULL);
+    if (num_threads_per_node < num_threads_per_socket)
+    {
+        llc_cache->threads = num_threads_per_node;
+        uint32_t size = llc_cache->size;
+        double factor = (((double)num_threads_per_node)/((double)num_threads_per_socket));
+        llc_cache->size = (uint32_t)(size*factor);
+    }
+    return;
+}
+
 void
 hwloc_init_cacheTopology(void)
 {
@@ -396,6 +450,21 @@ hwloc_init_cacheTopology(void)
         id++;
     }
 
+    if (cpuid_info.family == P6_FAMILY)
+    {
+        switch (cpuid_info.model)
+        {
+            case HASWELL_EP:
+            case BROADWELL_E:
+            case BROADWELL_D:
+            case SKYLAKEX:
+                hwloc_split_llc_check(&cachePool[maxNumLevels-1]);
+                break;
+            default:
+                break;
+        }
+    }
+
     cpuid_topology.numCacheLevels = maxNumLevels;
     cpuid_topology.cacheLevels = cachePool;
     return;
