@@ -5,14 +5,14 @@
  *
  *      Description:  Interface to the procfs/sysfs based topology backend
  *
- *      Version:   4.3.3
- *      Released:  09.11.2018
+ *      Version:   4.3.4
+ *      Released:  05.04.2019
  *
  *      Authors:  Jan Treibig (jt), jan.treibig@gmail.com,
  *                Thomas Roehl (tr), thomas.roehl@googlemail.com
  *      Project:  likwid
  *
- *      Copyright (C) 2018 RRZE, University Erlangen-Nuremberg
+ *      Copyright (C) 2019 RRZE, University Erlangen-Nuremberg
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -34,6 +34,10 @@
 #include <topology_proc.h>
 #include <affinity.h>
 #include <cpuid.h>
+#include <unistd.h>
+#include <dirent.h>
+#include <sys/types.h>
+#include <sys/stat.h>
 
 /* #####   FUNCTION DEFINITIONS  -  LOCAL TO THIS SOURCE FILE   ########### */
 static int
@@ -91,6 +95,15 @@ get_listPosition(int ownid, bstring list)
     return -1;
 }
 
+static int
+get_listLength(bstring list)
+{
+    struct bstrList* tokens = bsplit(list,(char) ',');
+    int len = tokens->qty;
+    bstrListDestroy(tokens);
+    return len;
+}
+
 static int
 fillList(int* outList, int outOffset, bstring list)
 {
@@ -259,7 +272,14 @@ proc_init_cpuFeatures(void)
     ret = 0;
     while( fgets(buf, sizeof(buf)-1, file) )
     {
-        if (strncmp(buf, "flags", 5) == 0 || strncmp(ident, "Features", 8) == 0)
+        ret = sscanf(buf, "%s\t:", &(ident[0]));
+#ifdef __x86_64
+        if (ret != 1 || strcmp(ident,"flags") != 0 || strcmp(ident, "Features") != 0)
+#endif
+        {
+            continue;
+        }
+        else
         {
             ret = 1;
             break;
@@ -270,10 +290,11 @@ proc_init_cpuFeatures(void)
     {
         return;
     }
-    buf[strcspn(buf, "\n")] = '\0';
+
     cpuid_info.featureFlags = 0;
     cpuid_info.features = (char*) malloc(MAX_FEATURE_STRING_LENGTH*sizeof(char));
     cpuid_info.features[0] = '\0';
+    buf[strcspn(buf, "\n")] = '\0';
     cptr = strtok(&(buf[6]),delimiter);
     while (cptr != NULL)
     {
@@ -419,11 +440,16 @@ proc_init_nodeTopology(cpu_set_t cpuSet)
     bstring file;
     int (*ownatoi)(const char*);
     ownatoi = &atoi;
+    int last_socket = -1;
+    int num_sockets = 0;
+    int num_cores_per_socket = 0;
+    int num_threads_per_core = 0;
 
     hwThreadPool = (HWThread*) malloc(cpuid_topology.numHWThreads * sizeof(HWThread));
     for (uint32_t i=0;i<cpuid_topology.numHWThreads;i++)
     {
         hwThreadPool[i].apicId = i;
+        cpudir = bformat("/sys/devices/system/cpu/cpu%d/topology",i);
         hwThreadPool[i].threadId = -1;
         hwThreadPool[i].coreId = -1;
         hwThreadPool[i].packageId = -1;
@@ -432,20 +458,29 @@ proc_init_nodeTopology(cpu_set_t cpuSet)
         {
             hwThreadPool[i].inCpuSet = 1;
         }
-        cpudir = bformat("/sys/devices/system/cpu/cpu%d/topology",i);
+        file = bformat("%s/physical_package_id", bdata(cpudir));
+        if (NULL != (fp = fopen (bdata(file), "r")))
+        {
+            bstring src = bread ((bNread) fread, fp);
+            int packageId = ownatoi(bdata(src));
+            hwThreadPool[i].packageId = packageId;
+            if (packageId > last_socket)
+            {
+                num_sockets++;
+                last_socket = packageId;
+            }
+            fclose(fp);
+        }
+        bdestroy(file);
         file = bformat("%s/core_id", bdata(cpudir));
         if (NULL != (fp = fopen (bdata(file), "r")))
         {
             bstring src = bread ((bNread) fread, fp);
             hwThreadPool[i].coreId = ownatoi(bdata(src));
-            fclose(fp);
-        }
-        bdestroy(file);
-        file = bformat("%s/physical_package_id", bdata(cpudir));
-        if (NULL != (fp = fopen (bdata(file), "r")))
-        {
-            bstring src = bread ((bNread) fread, fp);
-            hwThreadPool[i].packageId = ownatoi(bdata(src));
+            if (hwThreadPool[i].packageId == 0)
+            {
+                num_cores_per_socket++;
+            }
             fclose(fp);
         }
         bdestroy(file);
@@ -454,6 +489,11 @@ proc_init_nodeTopology(cpu_set_t cpuSet)
         {
             bstring src = bread ((bNread) fread, fp);
             hwThreadPool[i].threadId = get_listPosition(i, src);
+            if (hwThreadPool[i].packageId == 0 &&
+                hwThreadPool[i].coreId == 0)
+            {
+                num_threads_per_core++;
+            }
             fclose(fp);
         }
         bdestroy(file);
@@ -466,9 +506,65 @@ proc_init_nodeTopology(cpu_set_t cpuSet)
         bdestroy(cpudir);
     }
     cpuid_topology.threadPool = hwThreadPool;
+    cpuid_topology.numSockets = num_sockets;
+    cpuid_topology.numCoresPerSocket = num_cores_per_socket;
+    cpuid_topology.numThreadsPerCore = num_threads_per_core;
     return;
 }
 
+void proc_split_llc_check(CacheLevel* llc_cache)
+{
+    int num_sockets = cpuid_topology.numSockets;
+    int num_nodes = 0;
+    int num_threads_per_node = 0;
+    int num_threads_per_socket = (cpuid_topology.numCoresPerSocket * cpuid_topology.numThreadsPerCore) / num_sockets;
+    struct dirent *ep = NULL;
+    DIR *dp = NULL;
+    dp = opendir("/sys/devices/system/node");
+    if (dp == NULL)
+    {
+        fprintf(stderr, "No NUMA support (no folder %s)\n", "/sys/devices/system/node");
+        return;
+    }
+    while (ep = readdir(dp))
+    {
+        if (strncmp(ep->d_name, "node", 4) == 0)
+        {
+            num_nodes++;
+        }
+    }
+    closedir(dp);
+    dp = opendir("/sys/devices/system/node/node0/");
+    if (dp == NULL)
+    {
+        fprintf(stderr, "No NUMA support (no folder %s)\n", "/sys/devices/system/node/node0/");
+        return;
+    }
+    while (ep = readdir(dp))
+    {
+        if (strncmp(ep->d_name, "cpu", 3) == 0 &&
+            ep->d_name[strlen(ep->d_name)-1] >= '0' &&
+            ep->d_name[strlen(ep->d_name)-1] <= '9')
+        {
+            num_threads_per_node++;
+        }
+    }
+    closedir(dp);
+    if (num_sockets == num_nodes)
+    {
+        return;
+    }
+    if (num_threads_per_node < num_threads_per_socket)
+    {
+        llc_cache->threads = num_threads_per_node;
+        uint32_t size = llc_cache->size;
+        double factor = (((double)num_threads_per_node)/((double)num_threads_per_socket));
+        llc_cache->size = (uint32_t)(size*factor);
+    }
+    return;
+}
+
+
 void
 proc_init_cacheTopology(void)
 {
